BuildOptions class final
Constructors
Properties
- dartExecutable → String
-
final
- defaultEntry → String
-
final
- entry → String
-
final
- fallbackEntry → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- outDir → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- silent → bool
-
final
- workingDirectory → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited