Headers class
A mutable, case-insensitive HTTP headers collection.
- Inheritance
-
- Object
- IterableBase<
MapEntry< String, String> > - Headers
Constructors
Properties
-
first
→ MapEntry<
String, String> -
The first element.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Whether this collection has no elements.
no setterinherited
- isNotEmpty → bool
-
Whether this collection has at least one element.
no setterinherited
-
iterator
→ Iterator<
MapEntry< String, String> > -
A new
Iteratorthat allows iterating the elements of thisIterable.no setteroverride -
last
→ MapEntry<
String, String> -
The last element.
no setterinherited
- length → int
-
The number of elements in this Iterable.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
single
→ MapEntry<
String, String> -
Checks that this iterable has only one element, and returns that element.
no setterinherited
Methods
-
any(
bool test(MapEntry< String, String> element)) → bool -
Checks whether any element of this iterable satisfies
test.inherited -
append(
String name, Object value) → void - Adds a header value.
-
cast<
R> () → Iterable< R> -
A view of this iterable as an iterable of
Rinstances.inherited -
clear(
) → void - Removes all headers.
-
clone(
) → Headers - Creates a deep copy of this header collection.
-
contains(
Object? element) → bool -
Whether the collection contains an element equal to
element.inherited -
delete(
String name) → void -
Deletes all values by
name. -
elementAt(
int index) → MapEntry< String, String> -
Returns the
indexth element.inherited -
every(
bool test(MapEntry< String, String> element)) → bool -
Checks whether every element of this iterable satisfies
test.inherited -
expand<
T> (Iterable< T> toElements(MapEntry<String, String> element)) → Iterable<T> -
Expands each element of this Iterable into zero or more elements.
inherited
-
firstWhere(
bool test(MapEntry< String, String> element), {MapEntry<String, String> orElse()?}) → MapEntry<String, String> -
The first element that satisfies the given predicate
test.inherited -
fold<
T> (T initialValue, T combine(T previousValue, MapEntry< String, String> element)) → T -
Reduces a collection to a single value by iteratively combining each
element of the collection with an existing value
inherited
-
followedBy(
Iterable< MapEntry< other) → Iterable<String, String> >MapEntry< String, String> > -
Creates the lazy concatenation of this iterable and
other.inherited -
forEach(
void action(MapEntry< String, String> element)) → void -
Invokes
actionon each element of this iterable in iteration order.inherited -
get(
String name) → String? -
Returns a merged value for
name. -
getAll(
String name) → List< String> -
Returns all values by
name, preserving insertion order. -
getSetCookie(
) → List< String> -
Returns all
set-cookievalues. -
has(
String name) → bool -
Returns whether
nameexists. -
join(
[String separator = ""]) → String -
Converts each element to a String and concatenates the strings.
inherited
-
lastWhere(
bool test(MapEntry< String, String> element), {MapEntry<String, String> orElse()?}) → MapEntry<String, String> -
The last element that satisfies the given predicate
test.inherited -
map<
T> (T toElement(MapEntry< String, String> e)) → Iterable<T> -
The current elements of this iterable modified by
toElement.inherited -
names(
) → Iterable< String> - Returns normalized header names in insertion order (without duplicates).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reduce(
MapEntry< String, String> combine(MapEntry<String, String> value, MapEntry<String, String> element)) → MapEntry<String, String> -
Reduces a collection to a single value by iteratively combining elements
of the collection using the provided function.
inherited
-
set(
String name, Object value) → void -
Replaces all values for
namewithvalue. -
singleWhere(
bool test(MapEntry< String, String> element), {MapEntry<String, String> orElse()?}) → MapEntry<String, String> -
The single element that satisfies
test.inherited -
skip(
int count) → Iterable< MapEntry< String, String> > -
Creates an Iterable that provides all but the first
countelements.inherited -
skipWhile(
bool test(MapEntry< String, String> value)) → Iterable<MapEntry< String, String> > -
Creates an
Iterablethat skips leading elements whiletestis satisfied.inherited -
take(
int count) → Iterable< MapEntry< String, String> > -
Creates a lazy iterable of the
countfirst elements of this iterable.inherited -
takeWhile(
bool test(MapEntry< String, String> value)) → Iterable<MapEntry< String, String> > -
Creates a lazy iterable of the leading elements satisfying
test.inherited -
toList(
{bool growable = true}) → List< MapEntry< String, String> > -
Creates a List containing the elements of this Iterable.
inherited
-
toMap(
) → Map< String, String> -
Returns a map representation where duplicate values are merged by
,. -
toSet(
) → Set< MapEntry< String, String> > -
Creates a Set containing the same elements as this iterable.
inherited
-
toString(
) → String -
Returns a string representation of (some of) the elements of
this.inherited -
where(
bool test(MapEntry< String, String> element)) → Iterable<MapEntry< String, String> > -
Creates a new lazy Iterable with all elements that satisfy the
predicate
test.inherited -
whereType<
T> () → Iterable< T> -
Creates a new lazy Iterable with all elements that have type
T.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited