passThroughOnException method
void
passThroughOnException()
Lets the worker continue through the platform exception pipeline.
Implementation
external void passThroughOnException();
Lets the worker continue through the platform exception pipeline.
external void passThroughOnException();