CloudflareRuntimeExtension<Env extends Object?, Request extends Object?> class
final
Exposes Cloudflare Worker host values through RequestContext.extension.
- Implemented types
Constructors
- CloudflareRuntimeExtension({Env? env, CloudflareExecutionContext? context, Request? request})
-
Creates a Cloudflare runtime extension snapshot.
const
Properties
- context → CloudflareExecutionContext?
-
Cloudflare's execution context for the current worker invocation.
final
- env → Env?
-
Cloudflare environment bindings for the current worker invocation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- request → Request?
-
The host-native request value for the current invocation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited