account property
JSObject?
get
account
Netlify account metadata for the current invocation, when available.
Implementation
external JSObject? get account;
Netlify account metadata for the current invocation, when available.
external JSObject? get account;