deploy property
JSObject?
get
deploy
Netlify deploy metadata for the current invocation, when available.
Implementation
external JSObject? get deploy;
Netlify deploy metadata for the current invocation, when available.
external JSObject? get deploy;