geo property
JSObject?
get
geo
Netlify geolocation metadata for the current invocation, when available.
Implementation
external JSObject? get geo;
Netlify geolocation metadata for the current invocation, when available.
external JSObject? get geo;