site property
JSObject?
get
site
Netlify site metadata for the current invocation, when available.
Implementation
external JSObject? get site;
Netlify site metadata for the current invocation, when available.
external JSObject? get site;