websocket library

Classes

BinaryDataReceived
Binary data received from the peer through the WebSocket.
CloseReceived
A close notification (Close frame) received from the peer through the WebSocket or a failure indication.
TextDataReceived
Text data received from the peer through the WebSocket.
WebSocket
The interface for WebSocket connections.
WebSocketEvent
An event received from the peer through the WebSocket.
WebSocketRequest
Request-scoped websocket upgrade capability exposed by a runtime.

Typedefs

WebSocketHandler = FutureOr<void> Function(WebSocket socket)
Handles an accepted websocket session after the host upgrade completes.

Exceptions / Errors

WebSocketConnectionClosed
Thrown if WebSocket.sendText, WebSocket.sendBytes, or WebSocket.close is called when the WebSocket is closed.
WebSocketException