BuildResult class final
Constructors
- BuildResult({required String entry, required String outDir, required String coreJsPath, required String executablePath})
-
const
Properties
- coreJsPath → String
-
final
- entry → String
-
final
- executablePath → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- outDir → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited