RequestContext class base
Adds per-request controls on top of the shared lifecycle context.
- Inheritance
-
- Object
- ServerLifecycleContext
- RequestContext
Constructors
-
RequestContext({required RuntimeInfo runtime, required RuntimeCapabilities capabilities, required void onWaitUntil(Future<
void> task), RuntimeExtension? extension, WebSocketRequest? webSocket}) - Creates a request context for a single incoming request.
Properties
- capabilities → RuntimeCapabilities
-
Declares which runtime capabilities are available for this invocation.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtime → RuntimeInfo
-
Identifies the runtime that is invoking the server.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- webSocket → WebSocketRequest?
-
Returns the request-scoped websocket upgrade capability when supported.
no setter
Methods
-
extension<
T extends RuntimeExtension> () → T? -
Returns the runtime-specific extension when it matches
T.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
waitUntil(
Future< void> task) → void - Registers a task that should outlive the immediate response.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited