Response class
Constructors
- Response([BodyInit? body, ResponseInit? init])
- Response.error()
-
factory
- Response.json(Object? data, [ResponseInit? init])
-
factory
- Response.redirect(Uri url, [int status = HttpStatus.found])
-
factory
Properties
- body → Body?
-
final
- bodyUsed → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- headers → Headers
-
final
- ok → bool
-
final
- redirected → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int
-
final
- statusText → String
-
final
- type → ResponseType
-
final
- url → String
-
final
Methods
-
arrayBuffer(
) → Future< Uint8List> -
blob(
) → Future< Blob> -
bytes(
) → Future< Uint8List> -
clone(
) → Response -
formData(
) → Future< FormData> -
json<
T> () → Future< T> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
text(
) → Future< String> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited