DenoRuntimeExtension class final
Exposes Deno-specific host objects through RequestContext.extension.
- Implemented types
Constructors
- DenoRuntimeExtension({DenoGlobal? deno, DenoHttpServerHost? server, DenoRequestHost? request})
-
Creates a Deno runtime extension snapshot.
const
- DenoRuntimeExtension.host()
-
Creates a host-level extension before the server starts handling requests.
factory
Properties
- deno → DenoGlobal?
-
The Deno global object when running on a Deno host.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- request → DenoRequestHost?
-
The raw Deno request for the active request, when one exists.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- server → DenoHttpServerHost?
-
The active Deno HTTP server, when the runtime is serving requests.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited